@@ -4,17 +4,17 @@ cache subsystem, typically used for storing package metadata
 
 __all__ = ("base", "bulk")
 
-from functools import partial
 import math
-import os
 import operator
+import os
+from functools import partial
 
 from snakeoil import klass
 from snakeoil.chksum import get_handler
 from snakeoil.mappings import ProtectedDict
 
-from pkgcore.cache import errors
-from pkgcore.ebuild.const import metadata_keys
+from ..ebuild.const import metadata_keys
+from . import errors
 
 
 class base:
@@ -218,7 +218,7 @@ class base:
         """takes a dict, returns a string representing said dict"""
         l = []
         converters = self.eclass_chf_serializers
-        for eclass, data in sorted(eclass_dict.items()):
+        for eclass, data in eclass_dict.items():
             l.append(eclass)
             l.extend(f(data) for f in converters)
         return self.eclass_splitter.join(l)
