@@ -28,6 +28,7 @@ from snakeoil.sequences import predicate_split, split_negations, stable_unique
 
 from ..binpkg import repository as binary_repo
 from ..cache.flat_hash import md5_cache
+from ..config import basics
 from ..config import errors as config_errors
 from ..config.domain import Failure
 from ..config.domain import domain as config_domain
@@ -620,52 +621,62 @@ class domain(config_domain):
             wrapped_repo = self.filter_repo(wrapped_repo)
         return wrapped_repo
 
-    def add_repo(self, path, config, name=None, configure=True):
+    def add_repo(self, path, config, configure=False, **kwargs):
         """Add an external repo to the domain."""
         path = os.path.abspath(path)
-        # don't recreate existing repos
-        for repo in self.source_repos_raw:
-            if repo.location == path:
-                return repo
+
+        # return repo if it's already registered
+        try:
+            return next(r for r in self.source_repos_raw if r.location == path)
+        except StopIteration:
+            pass
+
+        # forcibly create repo_config object, otherwise cached version might be used
         try:
-            # forcibly create repo_config object, otherwise cached version might be used
             repo_config = RepoConfig(path, disable_inst_caching=True)
         except OSError as e:
             raise repo_errors.InvalidRepo(str(e))
-        kwargs = {}
+
         if repo_config.cache_format is not None:
             # default to using md5 cache
             kwargs['cache'] = (md5_cache(path),)
-        repo_obj = ebuild_repo.tree(config, repo_config, **kwargs)
-        self.source_repos_raw += repo_obj
+        repo = ebuild_repo.tree(config, repo_config, **kwargs)
+        self.source_repos_raw += repo
+
+        # inject repo objects into config to dynamically register repo
+        data = {}
+        repo_conf_data = {
+            'class': 'pkgcore.ebuild.repo_objs.RepoConfig',
+            'location': path,
+        }
+        repo_data = {
+            'inherit': ('ebuild-repo-common',),
+            'repo_config': f'conf:{path}',
+        }
+        data[f'conf:{path}'] = basics.AutoConfigSection(repo_conf_data)
+        data[path] = basics.AutoConfigSection(repo_data)
+        config.update(data)
 
         # reset repo-related jit attrs
         for attr in (x for x in dir(self) if x.startswith('_jit_repo_')):
             setattr(self, attr, None)
 
         if configure:
-            return self._wrap_repo(repo_obj)
-        return repo_obj
+            repo = self._wrap_repo(repo)
+        return repo
 
-    def find_repo(self, path, config, configure=True):
+    def find_repo(self, path, config, configure=False):
         """Find and add an external repo to the domain given a path."""
-        repo = None
         path = os.path.abspath(path)
         with suppress_logging():
-            while True:
+            while (parent := os.path.dirname(path)) != path:
                 try:
-                    repo = self.add_repo(path, config=config, configure=configure)
-                    break
+                    return self.add_repo(path, config=config, configure=configure)
                 except repo_errors.InvalidRepo:
-                    parent = os.path.dirname(path)
-                    if parent == path:
-                        break
                     path = parent
-        return repo
 
     def _configure_repo(self, repo):
         """Configure a raw repo."""
-        configured_repo = repo
         if not repo.configured:
             pargs = [repo]
             try:
@@ -682,8 +693,8 @@ class domain(config_domain):
                 raise Failure(
                     f"failed configuring repo {repo!r}: "
                     f"configurable missing: {e}") from e
-            configured_repo = repo.configure(*pargs)
-        return configured_repo
+            repo = repo.configure(*pargs)
+        return repo
 
     def filter_repo(self, repo, pkg_masks=None, pkg_unmasks=None, pkg_filters=None,
                     pkg_accept_keywords=None, pkg_keywords=None, profile=True):
