@@ -8,25 +8,27 @@ __all__ = (
 )
 
 import configparser
-from collections import OrderedDict
 import errno
 import os
+from collections import OrderedDict
 
 from snakeoil.bash import read_bash_dict
-from snakeoil.currying import wrap_exception
 from snakeoil.compatibility import IGNORED_EXCEPTIONS
-from snakeoil.mappings import ImmutableDict, DictMixin
-from snakeoil.osutils import access, normpath, abspath, listdir_files, pjoin, ensure_dirs
+from snakeoil.mappings import DictMixin, ImmutableDict
+from snakeoil.osutils import access, listdir_files, pjoin
 
-from pkgcore import const, exceptions as base_errors
-from pkgcore.config import basics, errors as config_errors
-from pkgcore.config.hint import configurable
-from pkgcore.ebuild import const as econst, profiles, repo_objs
-from pkgcore.ebuild.misc import optimize_incrementals
-from pkgcore.ebuild.repository import errors as repo_errors
-from pkgcore.fs.livefs import sorted_scan
-from pkgcore.log import logger
-from pkgcore.pkgsets.glsa import SecurityUpgrades
+from .. import const
+from .. import exceptions as base_errors
+from ..config import basics
+from ..config import errors as config_errors
+from ..config.hint import configurable
+from ..fs.livefs import sorted_scan
+from ..log import logger
+from ..pkgsets.glsa import SecurityUpgrades
+from . import const as econst
+from . import profiles, repo_objs
+from .misc import optimize_incrementals
+from .repository import errors as repo_errors
 
 
 def my_convert_hybrid(manager, val, arg_type):
@@ -331,6 +333,7 @@ class PortageConfig(DictMixin):
                         f"repos.conf: parsing {fp!r}: "
                         f"{name!r} repo missing location setting, ignoring repo")
                     continue
+                location = os.path.expanduser(location)
                 if os.path.isabs(location):
                     repo_conf['location'] = location
                 else:
@@ -462,26 +465,24 @@ class PortageConfig(DictMixin):
         except FileNotFoundError:
             pass
 
-    def _find_profile_link(self):
-        make_profile = pjoin(self.dir, 'make.profile')
-        try:
-            return normpath(abspath(
-                pjoin(self.dir, os.readlink(make_profile))))
-        except EnvironmentError as e:
-            if e.errno in (errno.ENOENT, errno.EINVAL):
-                raise config_errors.UserConfigError(
-                    f"{make_profile!r} must be a symlink pointing to a real target") from e
-            raise config_errors.ComplexInstantiationError(
-                f"{make_profile!r}: unexpected error- {e.strerror}") from e
+    def _find_profile_path(self, profile_override):
+        if profile_override is None:
+            make_profile = pjoin(self.dir, 'make.profile')
+            if not os.path.islink(make_profile):
+                raise config_errors.UserConfigError(f'invalid symlink: {make_profile!r}')
+            path = os.path.realpath(make_profile)
+        else:
+            path = os.path.realpath(profile_override)
+
+        if not os.path.exists(path):
+            if profile_override is None:
+                raise config_errors.UserConfigError(f'broken symlink: {make_profile!r}')
+            else:
+                raise config_errors.UserConfigError(f'nonexistent profile: {profile_override!r}')
+        return path
 
     def _add_profile(self, profile_override=None):
-        if profile_override is None:
-            profile = self._find_profile_link()
-        else:
-            profile = normpath(abspath(profile_override))
-            if not os.path.exists(profile):
-                raise config_errors.UserConfigError(f"{profile!r} doesn't exist")
-
+        profile = self._find_profile_path(profile_override)
         paths = profiles.OnDiskProfile.split_abspath(profile)
         if paths is None:
             raise config_errors.UserConfigError(
@@ -509,7 +510,7 @@ class PortageConfig(DictMixin):
 
         fetcher_dict = {
             "class": "pkgcore.fetch.custom.fetcher",
-            "distdir": normpath(os.environ.get("DISTDIR", make_conf.pop("DISTDIR"))),
+            "distdir": os.path.normpath(os.environ.get("DISTDIR", make_conf.pop("DISTDIR"))),
             "command": fetchcommand,
             "resume_command": resumecommand,
             "attempts": make_conf.pop("FETCH_ATTEMPTS", '10'),
