@@ -51,17 +51,20 @@ class Maintainer:
     :ivar description: description of maintainership.
     :type maint_type: C{unicode} object or C{None}
     :ivar maint_type: maintainer type (person or project).
+    :type proxied: C{unicode} object or C{None}
+    :ivar proxied: proxied maintainer status (yes, no, proxy)
     """
 
-    __slots__ = ('email', 'description', 'name', 'maint_type')
+    __slots__ = ('email', 'description', 'name', 'maint_type', 'proxied')
 
-    def __init__(self, email=None, name=None, description=None, maint_type=None):
+    def __init__(self, email=None, name=None, description=None, maint_type=None, proxied=None):
         if email is None and name is None:
             raise ValueError('need at least one of name and email')
         self.email = email
         self.name = name
         self.description = description
         self.maint_type = maint_type
+        self.proxied = proxied
 
     def __str__(self):
         if self.name is not None:
@@ -83,6 +86,29 @@ class Maintainer:
                 return other == self.email or other == self.name
         return False
 
+    def __hash__(self):
+        return hash((self.email, self.name))
+
+
+class Upstream:
+    """Data on a single upstream."""
+
+    __slots__ = ('type', 'name')
+
+    def __init__(self, type, name):
+        self.type = type
+        self.name = name
+
+    def __eq__(self, other):
+        try:
+            return self.type == other.type and self.name == other.name
+        except AttributeError:
+            pass
+        return False
+
+    def __hash__(self):
+        return hash((self.type, self.name))
+
 
 class MetadataXml:
     """metadata.xml parsed results
@@ -92,7 +118,7 @@ class MetadataXml:
     """
 
     __slots__ = (
-        "__weakref__", "_maintainers", "_local_use",
+        "__weakref__", "_maintainers", "_upstreams", "_local_use",
         "_longdescription", "_source", "_stabilize_allarches",
     )
 
@@ -104,8 +130,8 @@ class MetadataXml:
             self._parse_xml()
         return getattr(self, attr)
 
-    for attr in ("maintainers", "local_use", "longdescription",
-                 "stabilize_allarches"):
+    for attr in ("maintainers", "upstreams", "local_use",
+                 "longdescription", "stabilize_allarches"):
         locals()[attr] = property(post_curry(_generic_attr, "_" + attr))
     del attr
 
@@ -116,6 +142,7 @@ class MetadataXml:
             tree = etree.parse(source)
         except etree.XMLSyntaxError as e:
             self._maintainers = ()
+            self._upstreams = ()
             self._local_use = mappings.ImmutableDict()
             self._longdescription = None
             self._source = None
@@ -137,12 +164,16 @@ class MetadataXml:
             try:
                 maintainers.append(Maintainer(
                     name=name, email=email, description=description,
-                    maint_type=x.get('type')))
+                    maint_type=x.get('type'), proxied=x.get('proxied')))
             except ValueError:
                 # ignore invalid maintainers that should be caught by pkgcheck
                 pass
 
         self._maintainers = tuple(maintainers)
+        self._upstreams = tuple(
+            Upstream(e.get('type'), e.text) for e in chain.from_iterable(tree.findall("upstream"))
+            if e.tag == 'remote-id'
+        )
 
         # Could be unicode!
         self._longdescription = None
@@ -180,6 +211,7 @@ class LocalMetadataXml(MetadataXml):
             MetadataXml._parse_xml(self, open(self._source, "rb", 32768))
         except FileNotFoundError:
             self._maintainers = ()
+            self._upstreams = ()
             self._local_use = mappings.ImmutableDict()
             self._longdescription = None
             self._source = None
@@ -688,6 +720,7 @@ class RepoConfig(syncable.tree, klass.ImmutableInstance, metaclass=WeakInstMeta)
     def __init__(self, location, config_name=None, syncer=None, profiles_base='profiles'):
         super().__init__(syncer)
         object.__setattr__(self, 'config_name', config_name)
+        object.__setattr__(self, 'external', (config_name is None))
         object.__setattr__(self, 'location', location)
         object.__setattr__(self, 'profiles_base', pjoin(self.location, profiles_base))
 
@@ -755,6 +788,7 @@ class RepoConfig(syncable.tree, klass.ImmutableInstance, metaclass=WeakInstMeta)
         sf(self, 'eapis_banned', tuple(iter_stable_unique(data.get('eapis-banned', '').split())))
         sf(self, 'properties_allowed', tuple(iter_stable_unique(data.get('properties-allowed', '').split())))
         sf(self, 'restrict_allowed', tuple(iter_stable_unique(data.get('restrict-allowed', '').split())))
+        sf(self, 'sign_commits', data.get('sign-commits', 'false').lower() == 'true')
 
         v = set(data.get('cache-formats', 'md5-dict').lower().split())
         if not v:
@@ -1001,11 +1035,11 @@ class SquashfsRepoConfig(RepoConfig):
         if os.path.exists(self._sqfs):
             self._mount_archive()
 
-    def _failed_cmd(self, ret, action):
-        if ret.returncode:
-            stderr = ret.stderr.decode().strip().lower()
+    def _failed_cmd(self, process, action):
+        if process.returncode:
+            stderr = process.stderr.decode().strip().lower()
             msg = f'failed {action} squashfs archive: {stderr}'
-            if ret.returncode == 1:
+            if process.returncode == 1:
                 raise PermissionDenied(self._sqfs, msg)
             else:
                 raise repo_errors.InitializationError(msg)
@@ -1023,30 +1057,25 @@ class SquashfsRepoConfig(RepoConfig):
         # First try using mount binary to automatically handle setting up loop
         # device -- this only works with real root perms since loopback device
         # mounting (losetup) doesn't work in user namespaces.
-        #
-        # TODO: switch to capture_output=True when >= py3.7
-        ret = subprocess.run(
-            ['mount', self._sqfs, self.location],
-            stderr=subprocess.PIPE, stdout=subprocess.PIPE,
-        )
+        p = subprocess.run(['mount', self._sqfs, self.location], capture_output=True)
 
-        if ret.returncode == 0:
+        if p.returncode == 0:
             return
-        elif ret.returncode not in (1, 32):
+        elif p.returncode not in (1, 32):
             # fail out if not a permissions issue (regular or loopback failure inside userns)
-            self._failed_cmd(ret, 'mounting')
+            self._failed_cmd(p, 'mounting')
 
         # fallback to using squashfuse
         try:
-            ret = subprocess.run(
+            p = subprocess.run(
                 ['squashfuse', '-o', 'nonempty', self._sqfs, self.location],
-                stderr=subprocess.PIPE, stdout=subprocess.PIPE)
+                capture_output=True)
         except FileNotFoundError as e:
             raise repo_errors.InitializationError(
                 f'failed mounting squashfs archive: {e.filename} required')
 
-        if ret.returncode:
-            self._failed_cmd(ret, 'mounting')
+        if p.returncode:
+            self._failed_cmd(p, 'mounting')
 
     def _umount_archive(self):
         """Unmount the squashfs archive."""
@@ -1064,13 +1093,10 @@ class SquashfsRepoConfig(RepoConfig):
 
         # fallback to using fusermount
         try:
-            # TODO: switch to capture_output=True when >= py3.7
-            ret = subprocess.run(
-                ['fusermount', '-u', self.location],
-                stderr=subprocess.PIPE, stdout=subprocess.PIPE)
+            p = subprocess.run(['fusermount', '-u', self.location], capture_output=True)
         except FileNotFoundError as e:
             raise repo_errors.InitializationError(
                 f'failed unmounting squashfs archive: {e.filename} required')
 
-        if ret.returncode:
-            self._failed_cmd(ret, 'unmounting')
+        if p.returncode:
+            self._failed_cmd(p, 'unmounting')
