@@ -12,6 +12,7 @@ from itertools import chain, filterfalse
 from operator import attrgetter
 from random import shuffle
 from sys import intern
+from weakref import WeakValueDictionary
 
 from snakeoil import chksum, klass
 from snakeoil.bash import iter_read_bash, read_dict
@@ -23,7 +24,6 @@ from snakeoil.obj import make_kls
 from snakeoil.osutils import listdir_dirs, listdir_files, pjoin
 from snakeoil.sequences import iflatten_instance, stable_unique
 from snakeoil.strings import pluralism as _pl
-from snakeoil.weakrefs import WeakValCache
 
 from .. import fetch
 from ..config.hint import ConfigHint, configurable
@@ -159,7 +159,6 @@ class repo_operations(_repo_ops.operations):
 
 def _sort_eclasses(config, repo_config):
     repo_path = repo_config.location
-    repo_id = repo_config.repo_id
     masters = repo_config.masters
     eclasses = []
 
@@ -174,8 +173,8 @@ def _sort_eclasses(config, repo_config):
         eclasses = [location]
     else:
         repo_map = {
-            r.repo_id: r.location for r in
-            config.objects['repo_config'].values()}
+            alias: r.location for r in config.objects['repo_config'].values()
+            for alias in r.aliases}
         eclasses = [repo_map[x] for x in masters]
 
     # add the repo's eclass directories if it's not specified.
@@ -245,53 +244,6 @@ class ProvidesRepo(util.SimpleTree):
         return False
 
 
-@configurable(
-    typename='repo',
-    types={
-        'repo_config': 'ref:repo_config', 'cache': 'refs:cache',
-        'eclass_cache': 'ref:eclass_cache',
-        'default_mirrors': 'list',
-        'allow_missing_manifests': 'bool'},
-    requires_config='config')
-def tree(config, repo_config, cache=(), eclass_cache=None,
-         default_mirrors=None, allow_missing_manifests=False):
-    """Initialize an unconfigured ebuild repository."""
-    repo_id = repo_config.repo_id
-    repo_path = repo_config.location
-
-    if repo_config.masters is None:
-        # if it's None, that means it's not a standalone, and is PMS, or misconfigured.
-        # empty tuple means it's a standalone repository
-        default = config.get_default('repo_config')
-        if default is None:
-            raise errors.InitializationError(
-                f"repo {repo_id!r} at {repo_path!r} requires missing default repo")
-
-    configured_repos = tuple(r.repo_id for r in config.objects['repo_config'].values())
-    missing = set(repo_config.masters).difference(configured_repos)
-    if missing:
-        missing = ', '.join(map(repr, sorted(missing)))
-        raise errors.InitializationError(
-            f'repo {repo_id!r} at path {repo_path!r} has missing masters: {missing}')
-
-    try:
-        masters = tuple(config.objects['repo'][r] for r in repo_config.masters)
-    except RecursionError:
-        repo_id = repo_config.repo_id
-        masters = ', '.join(repo_config.masters)
-        raise errors.InitializationError(
-            f'{repo_id!r} repo has cyclic masters: {masters}')
-
-    if eclass_cache is None:
-        eclass_cache = _sort_eclasses(config, repo_config)
-
-    return UnconfiguredTree(
-        repo_config.location, eclass_cache=eclass_cache, masters=masters, cache=cache,
-        default_mirrors=default_mirrors,
-        allow_missing_manifests=allow_missing_manifests,
-        repo_config=repo_config)
-
-
 class UnconfiguredTree(prototype.tree):
     """Raw implementation supporting standard ebuild tree.
 
@@ -358,8 +310,8 @@ class UnconfiguredTree(prototype.tree):
                 pjoin(self.location, 'eclass'), location=self.location)
         self.eclass_cache = eclass_cache
 
-        self.masters = masters
-        self.trees = tuple(masters) + (self,)
+        self.masters = tuple(masters)
+        self.trees = self.masters + (self,)
         self.licenses = repo_objs.Licenses(self.location)
         self.profiles = self.config.profiles
         if masters:
@@ -384,16 +336,17 @@ class UnconfiguredTree(prototype.tree):
         self._allow_missing_chksums = allow_missing_manifests
         self.package_class = self.package_factory(
             self, cache, self.eclass_cache, self.mirrors, self.default_mirrors)
-        self._shared_pkg_cache = WeakValCache()
+        self._shared_pkg_cache = WeakValueDictionary()
         self._bad_masked = RestrictionRepo(repo_id='bad_masked')
         self.projects_xml = repo_objs.LocalProjectsXml(
             pjoin(self.location, 'metadata', 'projects.xml'))
 
-    repo_id = klass.alias_attr("config.repo_id")
-    repo_name = klass.alias_attr("config.repo_name")
-    aliases = klass.alias_attr("config.aliases")
+    repo_id = klass.alias_attr('config.repo_id')
+    repo_name = klass.alias_attr('config.repo_name')
+    aliases = klass.alias_attr('config.aliases')
     eapi = klass.alias_attr('config.eapi')
     is_supported = klass.alias_attr('config.eapi.is_supported')
+    external = klass.alias_attr('config.external')
     pkg_masks = klass.alias_attr('config.pkg_masks')
 
     @klass.jit_attr
@@ -631,7 +584,63 @@ class UnconfiguredTree(prototype.tree):
 
     def __setstate__(self, state):
         self.__dict__ = state.copy()
-        self.__dict__['_shared_pkg_cache'] = WeakValCache()
+        self.__dict__['_shared_pkg_cache'] = WeakValueDictionary()
+
+
+@configurable(
+    typename='repo',
+    types={
+        'repo_config': 'ref:repo_config', 'cache': 'refs:cache',
+        'eclass_cache': 'ref:eclass_cache',
+        'default_mirrors': 'list',
+        'allow_missing_manifests': 'bool'},
+    requires_config='config')
+def tree(config, repo_config, cache=(), eclass_cache=None,
+         default_mirrors=None, allow_missing_manifests=False,
+         tree_cls=UnconfiguredTree):
+    """Initialize an unconfigured ebuild repository."""
+    repo_id = repo_config.repo_id
+    repo_path = repo_config.location
+
+    if repo_config.masters is None:
+        # if it's None, that means it's not a standalone, and is PMS, or misconfigured.
+        # empty tuple means it's a standalone repository
+        default = config.get_default('repo_config')
+        if default is None:
+            raise errors.InitializationError(
+                f"repo {repo_id!r} at {repo_path!r} requires missing default repo")
+
+    # map external repo ids to their config names
+    config_map = {
+        r.repo_id: r.location for r in config.objects['repo_config'].values() if r.external}
+
+    try:
+        masters = []
+        missing = []
+        for r in repo_config.masters:
+            if repo := config.objects['repo'].get(config_map.get(r, r)):
+                masters.append(repo)
+            else:
+                missing.append(r)
+    except RecursionError:
+        repo_id = repo_config.repo_id
+        masters = ', '.join(repo_config.masters)
+        raise errors.InitializationError(
+            f'{repo_id!r} repo has cyclic masters: {masters}')
+
+    if missing:
+        missing = ', '.join(map(repr, sorted(missing)))
+        raise errors.InitializationError(
+            f'repo {repo_id!r} at path {repo_path!r} has missing masters: {missing}')
+
+    if eclass_cache is None:
+        eclass_cache = _sort_eclasses(config, repo_config)
+
+    return tree_cls(
+        repo_config.location, eclass_cache=eclass_cache, masters=masters, cache=cache,
+        default_mirrors=default_mirrors,
+        allow_missing_manifests=allow_missing_manifests,
+        repo_config=repo_config)
 
 
 class _RegenOpHelper:
