@@ -1,14 +1,8 @@
 """system/repository maintenance utility"""
 
-__all__ = (
-    "sync", "sync_main", "copy", "copy_main", "regen", "regen_main",
-    "perl_rebuild", "perl_rebuild_main", "env_update", "env_update_main",
-)
-
 import argparse
 import logging
 import os
-import re
 import textwrap
 import time
 from multiprocessing import cpu_count
@@ -16,7 +10,7 @@ from multiprocessing import cpu_count
 from snakeoil.cli import arghparse
 from snakeoil.contexts import patch
 from snakeoil.fileutils import AtomicWriteFile
-from snakeoil.osutils import listdir_dirs, pjoin
+from snakeoil.osutils import pjoin
 from snakeoil.sequences import iter_stable_unique
 
 from ..cache.flat_hash import md5_cache
@@ -31,9 +25,7 @@ from ..operations import OperationError
 from ..operations import observer as observer_mod
 from ..package import mutated
 from ..package.errors import MetadataException
-from ..restrictions import packages
 from ..util import commandline
-from ..util.parserestrict import parse_match
 
 pkgcore_opts = commandline.ArgumentParser(domain=False, script=(__file__, __name__))
 argparser = commandline.ArgumentParser(
@@ -338,44 +330,6 @@ def regen_main(options, out, err):
     return int(any(ret))
 
 
-perl_rebuild = subparsers.add_parser(
-    "perl-rebuild", parents=shared_options_domain,
-    description="EXPERIMENTAL: perl-rebuild support for use after upgrading perl")
-perl_rebuild.add_argument(
-    "new_version", help="the new perl version; 5.12.3 for example")
-@perl_rebuild.bind_main_func
-def perl_rebuild_main(options, out, err):
-    path = pjoin(options.domain.root, "usr/lib/perl5", options.new_version)
-    if not os.path.exists(path):
-        perl_rebuild.error(
-            f"version {options.new_version} doesn't seem to be installed; "
-            f"can't find it at {path!r}")
-
-    base = pjoin(options.domain.root, "/usr/lib/perl5")
-    potential_perl_versions = [
-        x.replace(".", "\\.") for x in listdir_dirs(base)
-        if x.startswith("5.") and x != options.new_version]
-
-    if len(potential_perl_versions) == 1:
-        subpattern = potential_perl_versions[0]
-    else:
-        subpattern = "(?:%s)" % ("|".join(potential_perl_versions),)
-    matcher = re.compile(
-        "/usr/lib(?:64|32)?/perl5/(?:%s|vendor_perl/%s)" %
-        (subpattern, subpattern)).match
-
-    for pkg in options.domain.all_installed_repos:
-        contents = getattr(pkg, 'contents', ())
-        if not contents:
-            continue
-        # scan just directories...
-        for fsobj in contents.iterdirs():
-            if matcher(fsobj.location):
-                out.write(str(pkg.unversioned_atom))
-                break
-    return 0
-
-
 env_update = subparsers.add_parser(
     "env-update", description="update env.d and ldconfig",
     parents=shared_options_domain)
@@ -436,104 +390,6 @@ def mirror_main(options, out, err):
     return 0
 
 
-digest = subparsers.add_parser(
-    "digest", parents=shared_options_domain,
-    description="update package manifests")
-digest.add_argument(
-    'target', nargs='*',
-    help="packages matching any of these restrictions will have their "
-         "manifest/digest updated",
-    docs="""
-        Packages matching any of these restrictions will have their manifest
-        entries updated; however, if no target is specified one of the
-        following two cases occurs:
-
-        - If a repo is specified, the entire repo is manifested.
-        - If a repo isn't specified, a path restriction is created based on the
-          current working directory. In other words, if `pmaint digest` is run
-          within an ebuild's directory, all the ebuilds within that directory
-          will be manifested. If the current working directory isn't
-          within any configured repo, all repos are manifested.
-    """)
-digest_opts = digest.add_argument_group("subcommand options")
-digest_opts.add_argument(
-    "-f", "--force", help="forcibly remanifest specified packages",
-    action='store_true',
-    docs="""
-        Force package manifest files to be rewritten. Note that this requires
-        downloading all distfiles.
-    """)
-digest_opts.add_argument(
-    "-m", "--mirrors", help="enable fetching from Gentoo mirrors",
-    action='store_true',
-    docs="""
-        Enable checking Gentoo mirrors first for distfiles. This is disabled by
-        default because manifest generation is often performed when adding new
-        ebuilds with distfiles that aren't on Gentoo mirrors yet.
-    """)
-digest_opts.add_argument(
-    "-r", "--repo", help="target repository",
-    action=commandline.StoreRepoObject, repo_type='ebuild-raw', allow_external_repos=True,
-    docs="""
-        Target repository to search for matches. If no repo is specified all
-        ebuild repos are used.
-    """)
-@digest.bind_final_check
-def _digest_validate(parser, namespace):
-    repo = namespace.repo
-    targets = namespace.target
-    restrictions = []
-    if repo is not None:
-        if not targets:
-            restrictions.append(repo.path_restrict(repo.location))
-    else:
-        # if we're currently in a known ebuild repo use it, otherwise use all ebuild repos
-        cwd = os.getcwd()
-        repo = namespace.domain.ebuild_repos_raw.repo_match(cwd)
-        if repo is None:
-            repo = namespace.domain.all_ebuild_repos_raw
-
-        if not targets:
-            try:
-                restrictions.append(repo.path_restrict(cwd))
-            except ValueError:
-                # we're not in a configured repo so manifest everything
-                restrictions.extend(repo.path_restrict(x.location) for x in repo.trees)
-
-    if not repo.operations.supports("digests"):
-        digest.error("no repository support for digests")
-
-    for target in targets:
-        if os.path.exists(target):
-            try:
-                restrictions.append(repo.path_restrict(target))
-            except ValueError as e:
-                digest.error(e)
-        else:
-            try:
-                restrictions.append(parse_match(target))
-            except ValueError:
-                digest.error(f"invalid atom: {target!r}")
-
-    restriction = packages.OrRestriction(*restrictions)
-    namespace.restriction = restriction
-    namespace.repo = repo
-
-
-@digest.bind_main_func
-def digest_main(options, out, err):
-    repo = options.repo
-
-    failed = repo.operations.digests(
-        domain=options.domain,
-        restriction=options.restriction,
-        observer=observer_mod.formatter_output(out),
-        mirrors=options.mirrors,
-        force=options.force)
-
-    return int(any(failed))
-
-
 class EclassArgs(argparse.Action):
     """Determine eclass arguments for `pmaint eclass`."""
 
