@@ -16,7 +16,7 @@ class TestMetadataXml:
     @staticmethod
     def get_metadata_xml(maintainers=(), comments=(), local_use={},
                          longdescription=None, maint_type=None,
-                         stabilize_allarches=False):
+                         proxied=None, stabilize_allarches=False):
         cs = '\n'.join(comments)
         ms = us = ls = ""
         if maintainers:
@@ -29,8 +29,10 @@ class TestMetadataXml:
                     ms[-1] += f"\n<description>{x[2]}</description>"
                 if len(x) > 3:
                     raise ValueError('maintainer data has too many fields')
-            maint_type = (f'type="{maint_type}"' if maint_type is not None else '')
-            ms = '\n'.join(f'<maintainer {maint_type}>{x}</maintainer>' for x in ms)
+            maint_type = f'type="{maint_type}"' if maint_type is not None else ''
+            proxied = f'proxied="{proxied}"' if proxied is not None else ''
+            ms = '\n'.join(f'<maintainer {maint_type} {proxied}>{x}</maintainer>'
+                           for x in ms)
         if local_use:
             us = ['<use>']
             for flag, desc in local_use.items():
@@ -72,6 +74,7 @@ f"""<?xml version="1.0" encoding="UTF-8"?>
         assert "funky monkey \N{SNOWMAN}" == mx.maintainers[0].name
         assert mx.maintainers[0].description is None
         assert mx.maintainers[0].maint_type is None
+        assert mx.maintainers[0].proxied is None
 
     def test_maintainer_with_desc(self):
         mx = self.get_metadata_xml(
@@ -83,6 +86,7 @@ f"""<?xml version="1.0" encoding="UTF-8"?>
         assert "foobar" == mx.maintainers[0].name
         assert "Foobar" == mx.maintainers[0].description
         assert mx.maintainers[0].maint_type is None
+        assert mx.maintainers[0].proxied is None
 
     def test_maintainer_with_type(self):
         mx = self.get_metadata_xml(
@@ -95,6 +99,21 @@ f"""<?xml version="1.0" encoding="UTF-8"?>
         assert "foobar" == mx.maintainers[0].name
         assert mx.maintainers[0].description is None
         assert "person" == mx.maintainers[0].maint_type
+        assert mx.maintainers[0].proxied is None
+
+    def test_maintainer_with_proxied(self):
+        mx = self.get_metadata_xml(
+            maintainers=(("foo@bar.com", "foobar"),),
+            maint_type='person',
+            proxied='yes')
+        assert ("foobar <foo@bar.com>",) == tuple(map(str, mx.maintainers))
+        assert "foo@bar.com" in mx.maintainers
+        assert "foobar" in mx.maintainers
+        assert "foo@bar.com" == mx.maintainers[0].email
+        assert "foobar" == mx.maintainers[0].name
+        assert mx.maintainers[0].description is None
+        assert "person" == mx.maintainers[0].maint_type
+        assert "yes" == mx.maintainers[0].proxied
 
     def test_local_use(self):
         # empty...
